==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkPlotSurface.java <==
// java wrapper for vtkPlotSurface object
//

package vtk;
import vtk.*;

public class vtkPlotSurface extends vtkPlot3D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean Paint_2(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_2(id0); }

  private native void SetInputData_3(vtkTable id0);
  public void SetInputData(vtkTable id0)
    { SetInputData_3(id0); }

  private native void SetInputData_4(vtkTable id0,String id1,String id2,String id3);
  public void SetInputData(vtkTable id0,String id1,String id2,String id3)
    { SetInputData_4(id0,id1,id2,id3); }

  private native void SetInputData_5(vtkTable id0,String id1,String id2,String id3,String id4);
  public void SetInputData(vtkTable id0,String id1,String id2,String id3,String id4)
    { SetInputData_5(id0,id1,id2,id3,id4); }

  private native void SetInputData_6(vtkTable id0,int id1,int id2,int id3);
  public void SetInputData(vtkTable id0,int id1,int id2,int id3)
    { SetInputData_6(id0,id1,id2,id3); }

  private native void SetXRange_7(double id0,double id1);
  public void SetXRange(double id0,double id1)
    { SetXRange_7(id0,id1); }

  private native void SetYRange_8(double id0,double id1);
  public void SetYRange(double id0,double id1)
    { SetYRange_8(id0,id1); }

  public vtkPlotSurface() { super(); }

  public vtkPlotSurface(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkPlotSurface.java <==
// java wrapper for vtkPlotSurface object
//

package vtk;
import vtk.*;

public class vtkPlotSurface extends vtkPlot3D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean Paint_2(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_2(id0); }

  private native void SetInputData_3(vtkTable id0);
  public void SetInputData(vtkTable id0)
    { SetInputData_3(id0); }

  private native void SetInputData_4(vtkTable id0,String id1,String id2,String id3);
  public void SetInputData(vtkTable id0,String id1,String id2,String id3)
    { SetInputData_4(id0,id1,id2,id3); }

  private native void SetInputData_5(vtkTable id0,String id1,String id2,String id3,String id4);
  public void SetInputData(vtkTable id0,String id1,String id2,String id3,String id4)
    { SetInputData_5(id0,id1,id2,id3,id4); }

  private native void SetInputData_6(vtkTable id0,int id1,int id2,int id3);
  public void SetInputData(vtkTable id0,int id1,int id2,int id3)
    { SetInputData_6(id0,id1,id2,id3); }

  private native void SetXRange_7(double id0,double id1);
  public void SetXRange(double id0,double id1)
    { SetXRange_7(id0,id1); }

  private native void SetYRange_8(double id0,double id1);
  public void SetYRange(double id0,double id1)
    { SetYRange_8(id0,id1); }

  public vtkPlotSurface() { super(); }

  public vtkPlotSurface(long id) { super(id); }
  public native long   VTKInit();

}
